@@ -81,6 +81,7 @@ summarize_se_impl <- function(.data, ...,
   row_names <- col_names <- NULL
   grouped_rows <- is_grouped_rows(.groups)
   grouped_cols <- is_grouped_cols(.groups)
+  .byrow <- FALSE
   if (grouped_rows || "rows" %in% ctxs) {
     # get all chop data, groups and evaled
     row_chops <- chops$rows
@@ -96,6 +97,7 @@ summarize_se_impl <- function(.data, ...,
     if (.retain && !grouped_rows) {
       row_chops_sizes <- .nrow <- nrow(.data)
     } else {
+      .byrow <- TRUE
       row_chops_sizes <- .nrow <- 1L
       if (grouped_rows) {
         .nrow <- nrow(.groups$row_groups)
@@ -134,6 +136,7 @@ summarize_se_impl <- function(.data, ...,
     if (.retain && !grouped_cols) {
       col_chops_sizes <- .ncol <- ncol(.data)
     } else {
+      .byrow <- FALSE
       col_chops_sizes <- .ncol <- 1L
       if (grouped_cols) {
         .ncol <- nrow(.groups$col_groups)
@@ -203,7 +206,8 @@ summarize_se_impl <- function(.data, ...,
     map(
       matrix,
       nrow = .nrow,
-      ncol = .ncol
+      ncol = .ncol,
+      byrow = .byrow
     )
 
   out <- SummarizedExperiment(
@@ -228,7 +232,6 @@ summarize_se_impl <- function(.data, ...,
 summarise.PlySummarizedExperiment <- summarize.PlySummarizedExperiment
 
 
-
 assert_chops_size <- function(chops, size = 1L) {
   imap(
     chops,
